@@ -1,6 +1,6 @@
 package Markdown::Pod;
 {
-  $Markdown::Pod::VERSION = '0.003';
+  $Markdown::Pod::VERSION = '0.004';
 }
 # ABSTRACT: Convert Markdown to POD
 
@@ -78,10 +78,11 @@ sub markdown_to_pod {
 __PACKAGE__->meta->make_immutable;
 1;
 
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -89,7 +90,7 @@ Markdown::Pod - Convert Markdown to POD
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -150,20 +151,25 @@ L<Text::MultiMarkdown>, L<Text::Markdown>
 
 Keedi Kim - 김도형 <keedi@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
 
 Abigail (ABIGAIL)
 
+=item *
+
+Jason McIntosh (JMAC)
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Keedi Kim.
+This software is copyright (c) 2013 by Keedi Kim.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
